<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="am_ET">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation type="vanished">ምስሎች</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation type="unfinished">የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">ዳይሬክቶሪ መክፈቻ</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>እርስዎ ይህን ምስል ለ ማየት በቂ ፍቃድ የለዎትም</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">መሰረዣ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>ስም</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>አይነት</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>የ ተሻሻለበት ቀን</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>የ ፋይል መጠን</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>የ ተጋለጠበት ዘዴ </translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>የ ተጋለጠበት ፕሮግራም </translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>የ ተጋለጠበት ጊዜ</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>ፍላሽ</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>ብርሃን መቆጣጠሪያ</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>የ ትኩረት እርዝመት </translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>ከፍተኛ ብርሃን መቆጣጠሪያ</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>የ ብርሃን ፍጥነት</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>ነጭ ማካካሻ</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>ፍላሽ ማካካሻ</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>የ ሌንስ አይነት</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>የ ቀለም ቦታ</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>የ ካሜራው አይነት</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="vanished">መሸፈኛ</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="vanished">መቀየሪያ</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="vanished">ተንሸራታች</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation type="vanished">ቀለበት</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation type="vanished">ዳይሬክቶሪ ይምረጡ</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation type="vanished">የዚህ ዳይሬክቶሪ ማዋሀጃ ተሰናክሏል</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation type="vanished">ፎልደር መጨመሪያ</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation type="vanished">የ ዳይሬክቶሪ ማዋሀጃ አስተዳዳሪ</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation type="vanished">የ ዳይሬክቶሪ ዝርዝር ባዶ ነው</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation type="vanished">ማዋሀጃ መሰረዣ </translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="vanished">ምስሎች</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation type="vanished">አካሉ ተወግዷል</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation type="vanished">ዳይሬክቶሪው አልተገኘም</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation type="vanished">በ ማስላት ላይ...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>ምስል በ መመልከት ላይ</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">አልበም</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>ማሰናጃ</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">መመልከቻ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="vanished">ማሳያ መጨረሻ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">የማልወዳቸው</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>ያለፈው</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ይቀጥሉ</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation type="vanished">ያለፈው መመልከቻ</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation type="vanished">የሚቀጥለው መመልከቻ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">አዲስ አልበም</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>አቋራጭ ማሳያ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">ማጥፊያ</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">ከ ሙሉ መመልከቻ ዘዴ መውጫ</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="vanished">እባክዎን አዲስ አቋራጭ ያስገቡ </translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">አቋራጭ</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="vanished">ስእል መመልከቻ</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">አልበም</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="vanished">ነባር እንደ ነበር መመለሻ</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="vanished">መመልከቻ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="vanished">ማሳያ መጨረሻ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="vanished">ማተሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">ኮፒ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">የማልወዳቸው</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="vanished">የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">አዲስ አልበም</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>ያለፈው</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ይቀጥሉ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="vanished">ተንሸራታች ማሰናጃ</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="vanished">ውጤት መቀየሪያ</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">የሚፈጀው ጊዜ</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="vanished">መቀየሪያ የሚፈጀውን ጊዜ </translation>
    </message>
    <message>
        <source>second</source>
        <translation type="vanished">ሰከንድ</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished">እኔ የምወዳቸው</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">ያለፈው</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">ይቀጥሉ</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">ማጥፊያ</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation type="vanished">ወደ ኋላ</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation type="vanished">የ ምስል አስተዳዳሪ</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>እኔ የምወዳቸው</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished">የማልወዳቸው</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">የምወዳቸው</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>ምንም የ ምስል ፋይል አልተገኘም</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="vanished">ተንሸራታች ማሰናጃ</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation type="vanished">ውጤት</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">የሚፈጀው ጊዜ</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">አቋራጭ</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">መመልከቻ</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">አልበም</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="vanished">አዲስ አልበም</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">ማሰናጃ</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation type="vanished">የ ሰአት መስመር</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="vanished">ወደ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="vanished">ወደ አዲስ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>ከ ሙሉ መመልከቻ ዘዴ መውጫ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>ማተሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">የማልወዳቸው</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>የ መቃኛ መስኮት ማሳያ</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>የ መቃኛ መስኮት መደበቂያ</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">ማጥፊያ</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
